@@ -1,7 +1,7 @@
 package BioX::Workflow;
 
 use 5.008_005;
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Moose;
 use File::Find::Rule;
@@ -708,10 +708,7 @@ Starting point.
 sub run {
     my($self) = shift;
 
-    #print "#!/bin/bash\n\n";
-    #if($self->by_sample_outdir){
-        #$self->auto_name(0);
-    #}
+    print "#!/bin/bash\n\n";
 
     $self->print_opts;
 
@@ -937,7 +934,8 @@ sub dothings {
 
     $key = $keys[0];
     $self->key($key);
-    $camel_key = decamelize($key);
+    #$camel_key = decamelize($key);
+    $camel_key= $key;
 
     if($self->auto_name){
         $self->outdir($self->outdir."/$camel_key");
@@ -1073,6 +1071,7 @@ sub write_process{
             if($self->by_sample_outdir){
                 my($tt, $key);
                 $tt = $self->outdir;
+                #$key = decamelize($self->key);
                 $key = $self->key;
                 $tt =~ s/$key/$sample\/$key/;
                 $self->outdir($tt);
@@ -1081,7 +1080,8 @@ sub write_process{
 
                 if($self->has_pkey){
                     $tt = $self->indir;
-                    $key = $self->pkey;
+                    #$key = decamelize($self->pkey);
+                    $key = $self->key;
                     $tt =~ s/$key/$sample\/$key/;
                     $self->indir($tt);
                     $DB::single=2;
